#
# spec file for package python-sentry-sdk
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# nothing provides python2-venusian >= 1.0 needed by python2-pyramid
%define skip_python2 1
Name:           python-sentry-sdk
Version:        0.14.4
Release:        lp152.2.1
Summary:        Python SDK for Sentry.io
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/getsentry/sentry-python
Source0:        https://github.com/getsentry/sentry-python/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module Flask >= 0.8}
BuildRequires:  %{python_module blinker >= 1.1}
BuildRequires:  %{python_module bottle >= 0.12.13}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module falcon >= 1.4}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module urllib3}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask >= 0.8
Requires:       python-blinker >= 1.1
Requires:       python-bottle >= 0.12.13
Requires:       python-certifi
Requires:       python-falcon >= 1.4
Requires:       python-urllib3
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Werkzeug}
BuildRequires:  %{python_module eventlet}
BuildRequires:  %{python_module gevent}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pyramid}
BuildRequires:  %{python_module pytest-localserver}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module rq}
BuildRequires:  %{python_module tornado}
BuildRequires:  %{python_module tox}
# /SECTION
%python_subpackages

%description
A Python SDK for Sentry.io.
https://sentry.io/for/python/

%prep
%setup -q -n sentry-python-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONDONTWRITEBYTECODE=1
export PYTEST_ADDOPTS="-W ignore::DeprecationWarning"
# do not test integration:
rm -r tests/integrations
# test_transport_works / test_transport_infinite_loop / test_simple_rate_limits/ test_data_category_limits / test_complex_limits_without_data_category stucks

# test_auto_enabling_integrations_catches_import_error asert False where False = ..., not sure
%pytest -k 'not (test_transport_works or test_auto_enabling_integrations_catches_import_error or test_filename or test_transport_infinite_loop or test_simple_rate_limits or test_data_category_limits or test_complex_limits_without_data_category)'

%files %{python_files}
%doc README.md CHANGES.md
%license LICENSE
%{python_sitelib}/*

%changelog
* Thu Jun 18 2020 Martin Hauke <mardnh@gmx.de>
- update to 0.14.4
  * Fix bugs in transport rate limit enforcement for specific data
    categories.
  * The bug should not have affected anybody because we do not yet
    emit rate limits for specific event types/data categories.
  * Fix a bug in capture_event where it would crash if given
    additional kwargs.
  * Fix a bug where contextvars from the request handler were
    inaccessible in AIOHTTP error handlers.
  * Fix a bug where the Celery integration would crash if newrelic
    instrumented Celery as well.
* Thu Mar 26 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.14.3
  * Attempt to use a monotonic clock to measure span durations in Performance/APM.
  * Avoid overwriting explicitly set user data in web framework integrations.
  * Allow to pass keyword arguments to `capture_event` instead of configuring the scope.
  * Feature development for session tracking.
* Wed Mar 18 2020 pgajdos@suse.com
- version update to 0.14.2
  * Fix a crash in the Django integration when used in combination with Django Rest Framework's test utilities for request.
  * Fix high memory consumption when sending a lot of errors in the same process. Particularly noticeable in async environments.
  * Show ASGI request data in Django 3.0
  * New integration for the Trytond ERP framework. Thanks n1ngu!
  * Fix trace continuation bugs in APM.
  * No longer report `asyncio.CancelledError` as part of AIOHTTP integration.
  * Fix package classifiers to mark this package as supporting Python 3.8. The SDK supported 3.8 before though.
  * Update schema sent for transaction events (transaction status).
  * Fix a bug where `None` inside request data was skipped/omitted.
  * Fix an issue with the ASGI middleware that would cause Uvicorn to infer the wrong ASGI versions and call the wrapped application with the wrong argument count.
  * Do not ignore the `tornado.application` logger.
  * The Redis integration now instruments Redis blaster for breadcrumbs and transaction spans.
- test at least something
- deleted sources
  - pytest.ini (not needed)
* Fri Nov  8 2019 Jimmy Berry <jberry@suse.com>
- Update to 0.13.2
  - Fix a bug in APM that would cause wrong durations to be
    displayed on non-UTC servers.
* Fri Oct 25 2019 Jimmy Berry <jberry@suse.com>
- Update to 0.13.1
  - Add new global functions for setting scope/context data.
  - Fix a bug that would make Django 1.11+ apps crash when using
    function-based middleware.
* Thu Oct 17 2019 Jimmy Berry <jberry@suse.com>
- Update to 0.13.0
  - Remove an old deprecation warning (behavior itself already
    changed since a long time).
  - The AIOHTTP integration now attaches the request body to crash
    reports. Thanks to Vitali Rebkavets!
  - Add an experimental PySpark integration.
  - First release to be tested under Python 3.8. No code changes
    were necessary though, so previous releases also might have
    worked.
* Wed Oct  2 2019 Jimmy Berry <jberry@suse.com>
- Update to 0.12.3
  - Various performance improvements to event sending.
  - Avoid crashes when scope or hub is racy.
  - Revert a change that broke applications using gevent and channels
    (in the same virtualenv, but different processes).
  - Fix a bug that made the SDK crash on unicode in SQL.
- Comment out test build dependencies since tests are disabled.
* Mon Sep 30 2019 Jimmy Berry <jberry@suse.com>
- Add pytest.ini source to ignore deprecation warning from eventlet
- Disable %%check since pytest does not want to follow documentation
* Mon Sep 30 2019 Jimmy Berry <jberry@suse.com>
- Update to 0.12.2
  - Temporarily remove sending of SQL parameters (as part of
    breadcrumbs or spans for APM) to Sentry to avoid memory
    consumption issues.
  - Fix a crash with ASGI (Django Channels) when the ASGI request
    type is neither HTTP nor Websockets.
* Thu Sep 19 2019 Jimmy Berry <jberry@suse.com>
- Update to 0.12.0
  - Fix a bug where the response object for httplib (or requests)
    was held onto for an unnecessarily long amount of time.
  - APM: Add spans for more methods on subprocess.Popen objects.
  - APM: Add spans for Django middlewares.
  - APM: Add spans for ASGI requests.
* Fri Aug 30 2019 Jimmy Berry <jberry@suse.com>
- Update to 0.11.2
  - fixed shutdown bug while runnign under eventlet
  - added missing data to Redis breadcrumbs
- Include build requirement on python eventlet module for the tests
  while exclusing a subset of new tests
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Trim time-dependent wording from description.
* Mon Aug 19 2019 Jimmy Berry <jberry@suse.com>
- Update to 0.11.1
  - Remove a faulty assertion (observed in environment with
    Django Channels and ASGI).
* Fri Aug 16 2019 Jimmy Berry <jberry@suse.com>
- Update to 0.11.0
  - mostly bug fixes
  - integration with SQLAlchemy and Apache Beam
* Mon Aug 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
- Run tests
* Fri Aug  9 2019 Jimmy Berry <jberry@suse.com>
- Set BuildArch to noarch.
* Fri Aug  9 2019 Jimmy Berry <jberry@suse.com>
- Update to 0.10.2.
* Fri Jun  7 2019 ecsos@opensuse.org
- initial version 0.9.0
